IRCTK-IRC(n) - n

# NAME

**irctk-irc** - the irctk irc namespace library

# SYNOPSIS

**irc cap** *chan tags capability*

**irc dial** *cmd callback*

**irc join** *chan tags channels* \[*keys*]

**irc nick** *chan tags nick*

**irc notice** *chan tags target* \[*args*]

**irc part** *chan tags channels* \[*args*]

**irc ping** *chan tags text*

**irc pong** *chan tags text*

**irc privmsg** *chan tags target* \[*args*]

**irc quit** *chan tags* \[*text*]

**irc receive** *chan*

**irc register** *chan tags user nick pass mode name*

**irc send** *chan tags cmd* \[*args*]

# DESCRIPTION

The irc namespace implements the IRC client specification as defined in
RFC2812 and a subset of the modern IRCv3 specification.

The
**irc dial**
command must be used to establish a connection to an irc server.
*cmd*
is a shell script that will be launched as a subprocess
and connected to
irctk(1)
through a bidirectional pipe, exchanging IRC commands through the
subprocess standard input and standard output channels.
In effect, the subprocess is responsible for the whole transport layer.
The
*callback*
argument will be called whenever new data are ready to on the read side of
the established communication channel and it will be called with the
form:

	callback chan

where
*chan*
is the communication channel just created.
The returned channel must then be passed to all the other commands
when a specific IRC operation must be performed.

The
**irc receive**
command can be called to receive a new IRC message from the specified
*chan*
message in a structured form.
The command returns a dictionary containing the following fields:

tags

> Dictionary containing all the processed IRCv3 tags stored as key-value
> pairs.

server

> The host the message is coming from

user

> The user that sent the message

nick

> The nickname of the user that sent the message, or the server that
> forwarded it if it was generated by one of the IRC network servers.

command

> The IRC command.

args

> List of command arguments

date

> Timestamp in UNIX epoch format.

The
**irc send**
command can be used to send an IRC message.
The message will be composed by zero or more
*tags*
passed as a dictionary containing a series of key-value pairs, an IRC
command passed as
*cmd*
and zero or more command arguments in
*args*.

## High level commands

The following high level commands should be used to send commands
to an IRC server.
If a command accept an arguments called
*tags*,
it means, as mentioned, a dictionary of key-value pairs identifying IRCv3
tags unless differently specified.

**irc cap**
is used to manage the IRCv3 capabilities subsystem of the server
connected to
*chan*.
By default, the
**irc cap**
command will send a
"CAP REQ *capability*"
command to the server, asking it to enable
*capability*
for the client.
The only exceptions for the
*capability*
arguments are:

ls

> Send a
> "CAP LS"
> command, asking the server for the list of capabilities it supports.

end

> Send a
> "CAP END"
> command, terminating the capabilities negotiation.

**irc register**
can be used to handle the client registration and login process to
the irc server.
If the
*pass*
argument is an empty string no PASS command will be issued.

**irc join**
can be used to join one or more IRC channels.
*channels*
and
*keys*
are comma-separated lists of IRC channels and related passwords,
in case joining a channel requires one.

**irc part**
can be used to leave one or more channels.
As for
**irc join**,
*channels*
is a comma-separated list of channels to leave.

**irc nick**
can be used to change the current user nickname.

**irc notice**
and
**irc privmsg**
sends, respectively, a NOTICE or a PRIVMSG command to the IRC server
directed at
*target*,
be it a channel or another user nickame.
*args*
is a variable-length list of strings that will compose the message to send.

**irc quit**
will QUIT the connection with
*text*
as a reason.
To note that the command does not close
*chan*.
It's responsibility of the caller to do so, either immediately, or after
receiving the related ERROR response from the irc server.

**irc ping**
and
**irc pong**
are used for the periodic check with the server if the connection is still
alive.
irctk(1)
may initiate e PING, waiting for the server response, or it may answer
with a PONG, if the PING is initiated by the irc server itself.
*text*
is the message passed to identify the PING or PONG transactions.

# RETURN VALUES

**irc dial**
returns the opened bi-directional channel on success, or nothing if
an error occured.

**irc receive**
returns a dictionary with the irc command field values, or -1 in case
an error occured during the read from the channel.

**irc send**
and all the other commands don't return any value at all.

In general, errors on the channel are expected to be handled in the
tcl event-loop, as a
"readable"
event is fired whenever a channel is closed, or if any error happened
on it.

# EXAMPLES

Dial to libera.chat, using
nc(1)
with TLS and use the
"newmsg"
Command as a callback:

	proc newmsg {ch} {
		set msg [irc receive $ch]
	
		if {$rmsg == -1} {
			if {[eof $chan]} {
				puts stderr "error on $chan"
				close $chan
			}
	
			return
		}
	
		puts $msg
	}
	
	irc dial "nc -c irc.libera.chat 6697" newmsg

# SEE ALSO

irctk(1),
irctk-exts(n),
irctk-gui(n),
irctk-irctk(n),
irctk-log(n)

# AUTHORS

Andrea Biscuola &lt;[a@abiscuola.com](mailto:a@abiscuola.com)&gt;  
Omar Polo &lt;[op@omarpolo.com](mailto:op@omarpolo.com)&gt;

OpenBSD 7.3 - August 18, 2023
